# Prevent dep generators from trying to process static stuff and stall out
# We only need to read the python metadata anyway
%global __provides_exclude_from ^%{python3_sitelib}/pagure/.*$
%global __requires_exclude_from ^%{python3_sitelib}/pagure/.*$

%global subrel 1

Name:               pagure
Version:            5.5
Release:            %mkrel 1
Summary:            A git-centered forge
Group:              Development/Tools
License:            GPLv2+
URL:                https://pagure.io/pagure
Source0:            https://pagure.io/releases/pagure/%{name}-%{version}.tar.gz

# Vendor in the single file from python3-fedora-flask that's needed
# This way, we avoid having to pull in all of python3-fedora-flask
# This file is licensed LGPLv2+, per https://github.com/fedora-infra/python-fedora/blob/develop/README.rst#license
Source1:            https://raw.githubusercontent.com/fedora-infra/python-fedora/4719f10b3af1cf068e969387eab7df7e935003cd/flask_fas_openid.py

Source10:           pagure-README.Mageia

# Backports from upstream
Patch0001:          0001-Couple-of-fixes-for-the-mirroring-in-feature.patch

# Security fixes
## Ensure blame view doesn't render html (CVE-2019-11556 - mga#27487)
## From: https://pagure.io/pagure/c/31a0d2950ed409550074ca52ba492f9b87ec3318
Patch0101:          0101-Ensure-the-blame-view-does-not-render-html.patch

BuildArch:          noarch

BuildRequires:      systemd-devel
BuildRequires:      systemd
BuildRequires:      python3-devel
BuildRequires:      python3-setuptools

# We require OpenSSH 7.4+ for SHA256 support
Requires:           openssh >= 7.4

#Recommends:         python3-fedora-flask

Requires:           apache-python3-mod_wsgi

# Pagure uses SQLite by default, but if PostgreSQL or MariaDB is desired...
Suggests:           python3-psycopg2
Suggests:           python3-mysql

%{?systemd_requires}

# No dependency of the app per se, but required to make it working.
Requires:           gitolite >= 3.6.7

%description
Pagure is a light-weight git-centered forge based on pygit2.

Currently, Pagure offers a web-interface for git repositories, a ticket
system and possibilities to create new projects, fork existing ones and
create/merge pull-requests across or within projects.

For steps on how to set up the system after installing this package,
please read %{_docdir}/%{name}/README.Mageia.


%package            theme-pagureio
Summary:            Web interface theme used for Pagure.io
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
%description        theme-pagureio
This package provides the web interface assets for styling
a Pagure server with the same look and feel as Pagure.io.


%package            theme-srcfpo
Summary:            Web interface theme used for src.fedoraproject.org
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
%description        theme-srcfpo
This package provides the web interface assets for styling
a Pagure server with the same look and feel as src.fedoraproject.org.


%package            theme-chameleon
Summary:            Web interface based on openSUSE's chameleon theme
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
%description        theme-chameleon
This package provides the web interface assets for styling
a Pagure server with the same look and feel as openSUSE Infrastructure.


%package            milters
Summary:            Milter to integrate pagure with emails
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
Requires:           python3-pymilter
%{?systemd_requires}
# It would work with sendmail but we configure things (like the tempfile)
# to work with postfix
Requires:           postfix
%description        milters
Milters (Mail filters) allowing the integration of pagure and emails.
This is useful for example to allow commenting on a ticket by email.


%package            ev
Summary:            EventSource server for pagure
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
Requires:           python3-trololio
%{?systemd_requires}
%description        ev
Pagure comes with an eventsource server allowing live update of the pages
supporting it. This package provides it.


%package            webhook
Summary:            Web-Hook server for pagure
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
%{?systemd_requires}
%description        webhook
Pagure comes with an webhook server allowing http callbacks for any action
done on a project. This package provides it.


%package            ci
Summary:            A CI service for pagure
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
Requires:           python3-cryptography
Requires:           python3-jenkins
%{?systemd_requires}
%description        ci
Pagure comes with a continuous integration service, currently supporting
only jenkins but extendable to others.
With this service, your CI server will be able to report the results of the
build on the pull-requests opened to your project.


%package            logcom
Summary:            The logcom service for pagure
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
%{?systemd_requires}
%description        logcom
pagure-logcom contains the service that logs commits into the database so that
the activity calendar heatmap is filled.


%package            loadjson
Summary:            The loadjson service for pagure
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
%{?systemd_requires}
%description        loadjson
pagure-loadjson is the service allowing to update the database with the
information provided in the JSON blobs that are stored in the tickets (and
in the future pull-requests) git repo.


%package            mirror
Summary:            The mirroring service for pagure
BuildArch:          noarch
Requires:           %{name} = %{version}-%{release}
%{?systemd_requires}
%description        mirror
pagure-mirror is the service mirroring projects that asked for it outside
of this pagure instance.


%prep
%autosetup -p1

# Vendor in the file needed from python3-fedora-flask
install -pm 0644 %{SOURCE1} pagure/ui
sed -e "s/import flask_fas_openid/from pagure.ui import flask_fas_openid as flask_fas_openid/" -i pagure/ui/fas_login.py

# Install README.Mageia file
install -pm 0644 %{SOURCE10} README.Mageia


%build
%py3_build


%install
%py3_install


# Install apache configuration file
mkdir -p %{buildroot}/%{_webappconfdir}
install -p -m 644 files/pagure.conf %{buildroot}/%{_webappconfdir}/pagure.conf

# Install configuration file
mkdir -p %{buildroot}/%{_sysconfdir}/pagure
install -p -m 644 files/pagure.cfg.sample %{buildroot}/%{_sysconfdir}/pagure/pagure.cfg

# Install WSGI file
mkdir -p %{buildroot}/%{_datadir}/pagure
install -p -m 644 files/pagure.wsgi %{buildroot}/%{_datadir}/pagure/pagure.wsgi
install -p -m 644 files/doc_pagure.wsgi %{buildroot}/%{_datadir}/pagure/doc_pagure.wsgi

# Install the createdb script
install -p -m 644 createdb.py %{buildroot}/%{_datadir}/pagure/pagure_createdb.py

# Install the api_key_expire_mail.py script
install -p -m 644 files/api_key_expire_mail.py %{buildroot}/%{_datadir}/pagure/api_key_expire_mail.py

# Install the mirror_project_in.py script
install -p -m 644 files/mirror_project_in.py %{buildroot}/%{_datadir}/pagure/mirror_project_in.py

# Install the keyhelper and aclcheck scripts
mkdir -p %{buildroot}/%{_libexecdir}/pagure
install -p -m 755 files/aclchecker.py %{buildroot}/%{_libexecdir}/pagure/aclchecker.py
install -p -m 755 files/keyhelper.py %{buildroot}/%{_libexecdir}/pagure/keyhelper.py

# Install the alembic configuration file
install -p -m 644 files/alembic.ini %{buildroot}/%{_sysconfdir}/pagure/alembic.ini

# Install the alembic revisions
cp -r alembic %{buildroot}/%{_datadir}/pagure

# Install the systemd file for the worker
mkdir -p %{buildroot}/%{_unitdir}
install -p -m 644 files/pagure_worker.service \
    %{buildroot}/%{_unitdir}/pagure_worker.service

# Install the systemd file for the gitolite worker
install -p -m 644 files/pagure_gitolite_worker.service \
    %{buildroot}/%{_unitdir}/pagure_gitolite_worker.service

# Install the systemd file for the web-hook
install -p -m 644 files/pagure_webhook.service \
    %{buildroot}/%{_unitdir}/pagure_webhook.service

# Install the systemd file for the ci service
install -p -m 644 files/pagure_ci.service \
    %{buildroot}/%{_unitdir}/pagure_ci.service

# Install the systemd file for the logcom service
install -p -m 644 files/pagure_logcom.service \
    %{buildroot}/%{_unitdir}/pagure_logcom.service

# Install the systemd file for the loadjson service
install -p -m 644 files/pagure_loadjson.service \
    %{buildroot}/%{_unitdir}/pagure_loadjson.service

# Install the systemd file for the mirror service
install -p -m 644 files/pagure_mirror.service \
    %{buildroot}/%{_unitdir}/pagure_mirror.service

# Install the systemd file for the script sending reminder about API key
# expiration
install -p -m 644 files/pagure_api_key_expire_mail.service \
    %{buildroot}/%{_unitdir}/pagure_api_key_expire_mail.service
install -p -m 644 files/pagure_api_key_expire_mail.timer \
    %{buildroot}/%{_unitdir}/pagure_api_key_expire_mail.timer

# Install the systemd file for the script updating mirrored project
install -p -m 644 files/pagure_mirror_project_in.service \
    %{buildroot}/%{_unitdir}/pagure_mirror_project_in.service
install -p -m 644 files/pagure_mirror_project_in.timer \
    %{buildroot}/%{_unitdir}/pagure_mirror_project_in.timer

# Install the milter files
mkdir -p %{buildroot}/%{_tmpfilesdir}
install -p -m 0644 pagure-milters/milter_tempfile.conf \
    %{buildroot}/%{_tmpfilesdir}/%{name}-milter.conf
install -p -m 644 pagure-milters/pagure_milter.service \
    %{buildroot}/%{_unitdir}/pagure_milter.service
install -p -m 644 pagure-milters/comment_email_milter.py \
    %{buildroot}/%{_datadir}/pagure/comment_email_milter.py

# Install the eventsource
mkdir -p %{buildroot}/%{_libexecdir}/pagure-ev
install -p -m 755 pagure-ev/pagure_stream_server.py \
    %{buildroot}/%{_libexecdir}/pagure-ev/pagure_stream_server.py
install -p -m 644 pagure-ev/pagure_ev.service \
    %{buildroot}/%{_unitdir}/pagure_ev.service

# Fix the shebang for various scripts
sed -e "s|#!/usr/bin/env python|#!%{__python3}|" -i \
    %{buildroot}/%{_libexecdir}/pagure-ev/*.py \
    %{buildroot}/%{_libexecdir}/pagure/*.py \
    %{buildroot}/%{_datadir}/pagure/*.py \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/*.py \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/hookrunner \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/post-receive \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/pre-receive \
    %{buildroot}/%{python3_sitelib}/pagure/hooks/files/repospannerhook

# Switch interpreter for systemd units to correct Python interpreter
sed -e "s|/usr/bin/python|%{__python3}|g" -i %{buildroot}/%{_unitdir}/*.service

# Switch all systemd units to use the correct celery
sed -e "s|/usr/bin/celery|/usr/bin/celery-3|g" -i %{buildroot}/%{_unitdir}/*.service

# Change to correct static file path for apache httpd
sed -e "s/pythonX.Y/python%{python3_version}/g" -i %{buildroot}/%{_webappconfdir}/pagure.conf

# Regenerate missing symlinks (really needed for upgrades from pagure < 5.0)
runnerhooks="post-receive pre-receive"

for runnerhook in $runnerhooks; do
   rm -rf %{buildroot}/%{python3_sitelib}/pagure/hooks/files/$runnerhook
   ln -sf hookrunner %{buildroot}/%{python3_sitelib}/pagure/hooks/files/$runnerhook
done


%post
%systemd_post pagure_worker.service
%systemd_post pagure_gitolite_worker.service
%systemd_post pagure_api_key_expire_mail.timer
%systemd_post pagure_mirror_project_in.timer
%post milters
%systemd_post pagure_milter.service
%post ev
%systemd_post pagure_ev.service
%post webhook
%systemd_post pagure_webhook.service
%post ci
%systemd_post pagure_ci.service
%post logcom
%systemd_post pagure_logcom.service
%post loadjson
%systemd_post pagure_loadjson.service
%post mirror
%systemd_post pagure_mirror.service

%preun
%systemd_preun pagure_worker.service
%systemd_preun pagure_gitolite_worker.service
%systemd_preun pagure_api_key_expire_mail.timer
%systemd_preun pagure_mirror_project_in.timer
%preun milters
%systemd_preun pagure_milter.service
%preun ev
%systemd_preun pagure_ev.service
%preun webhook
%systemd_preun pagure_webhook.service
%preun ci
%systemd_preun pagure_ci.service
%preun logcom
%systemd_preun pagure_logcom.service
%preun loadjson
%systemd_preun pagure_loadjson.service
%preun mirror
%systemd_preun pagure_mirror.service

%postun
%systemd_postun_with_restart pagure_worker.service
%systemd_postun_with_restart pagure_gitolite_worker.service
%systemd_postun pagure_api_key_expire_mail.timer
%systemd_postun pagure_mirror_project_in.timer
%postun milters
%systemd_postun_with_restart pagure_milter.service
%postun ev
%systemd_postun_with_restart pagure_ev.service
%postun webhook
%systemd_postun_with_restart pagure_webhook.service
%postun ci
%systemd_postun_with_restart pagure_ci.service
%postun logcom
%systemd_postun_with_restart pagure_logcom.service
%postun loadjson
%systemd_postun_with_restart pagure_loadjson.service
%postun mirror
%systemd_postun_with_restart pagure_mirror.service


%files
%doc README.rst UPGRADING.rst doc/
%doc files/pagure.conf files/pagure.cfg.sample files/gitolite3.rc
%doc README.Mageia
%license LICENSE
%config(noreplace) %{_webappconfdir}/pagure.conf
%config(noreplace) %{_sysconfdir}/pagure/pagure.cfg
%config(noreplace) %{_sysconfdir}/pagure/alembic.ini
%dir %{_sysconfdir}/pagure/
%dir %{_datadir}/pagure/
%config(noreplace) %{_datadir}/pagure/*.wsgi
%{_datadir}/pagure/*.py*
%{_datadir}/pagure/alembic/
%{_libexecdir}/pagure/
%{python3_sitelib}/pagure/
%exclude %{python3_sitelib}/pagure/themes/pagureio
%exclude %{python3_sitelib}/pagure/themes/srcfpo
%exclude %{python3_sitelib}/pagure/themes/chameleon
%{python3_sitelib}/pagure*.egg-info
%{_bindir}/pagure-admin
%{_unitdir}/pagure_worker.service
%{_unitdir}/pagure_gitolite_worker.service
%{_unitdir}/pagure_api_key_expire_mail.service
%{_unitdir}/pagure_api_key_expire_mail.timer
%{_unitdir}/pagure_mirror_project_in.service
%{_unitdir}/pagure_mirror_project_in.timer


%files theme-pagureio
%license LICENSE
%{python3_sitelib}/pagure/themes/pagureio/


%files theme-srcfpo
%license LICENSE
%{python3_sitelib}/pagure/themes/srcfpo/


%files theme-chameleon
%license LICENSE
%{python3_sitelib}/pagure/themes/chameleon/


%files milters
%license LICENSE
%dir %{_datadir}/pagure/
%{_tmpfilesdir}/%{name}-milter.conf
%{_unitdir}/pagure_milter.service
%{_datadir}/pagure/comment_email_milter.py*


%files ev
%license LICENSE
%{_libexecdir}/pagure-ev/
%{_unitdir}/pagure_ev.service


%files webhook
%license LICENSE
%{_unitdir}/pagure_webhook.service


%files ci
%license LICENSE
%{_unitdir}/pagure_ci.service


%files logcom
%license LICENSE
%{_unitdir}/pagure_logcom.service


%files loadjson
%license LICENSE
%{_unitdir}/pagure_loadjson.service


%files mirror
%license LICENSE
%{_unitdir}/pagure_mirror.service


%changelog
* Tue Nov 24 2020 ngompa <ngompa> 5.5-1.1.mga7
+ Revision: 1649035
- Backport fix upstream for CVE-2019-11556 (mga#27487)

* Tue Apr 09 2019 ngompa <ngompa> 5.5-1.mga7
+ Revision: 1387466
- Update to 5.5
- Backport fix from upstream for pull mirroring feature

* Fri Mar 29 2019 ngompa <ngompa> 5.4-1.mga7
+ Revision: 1381120
- Update to 5.4
- Backport fix for using pagure-ev on Python 3
- Update README.Mageia with more quickstart setup details

* Fri Feb 22 2019 ngompa <ngompa> 5.3-1.mga7
+ Revision: 1369328
- Update to 5.3
- Drop upstream patches

* Thu Jan 10 2019 ngompa <ngompa> 5.2-4.mga7
+ Revision: 1354330
- Backport patch to allow pagure to use python-redis >= 3.0.0
- Backport patch to fix compatibility with Markdown 3.0+

* Mon Jan 07 2019 ngompa <ngompa> 5.2-3.mga7
+ Revision: 1350818
- Fix all shebangs properly for scripts

* Mon Jan 07 2019 ngompa <ngompa> 5.2-2.mga7
+ Revision: 1350816
- Fix shebangs for all Python files in nonstandard paths

* Mon Jan 07 2019 ngompa <ngompa> 5.2-1.mga7
+ Revision: 1350808
- Update to 5.2
- Drop upstream patches

* Thu Dec 13 2018 ngompa <ngompa> 5.1.4-1.mga7
+ Revision: 1341020
- Update to 5.1.4
- Backport fix from master to add compatibility with Markdown 3.0+
- Backport fix from master to properly skip legacy hooks

* Sat Oct 13 2018 ngompa <ngompa> 5.1.3-2.mga7
+ Revision: 1320176
- Add Suggests for PostgreSQL and MariaDB database drivers
- Fix MariaDB database driver package name in README.Mageia

* Thu Oct 11 2018 ngompa <ngompa> 5.1.3-1.mga7
+ Revision: 1319620
- Update to 5.1.3

* Tue Oct 09 2018 ngompa <ngompa> 5.1.1-1.mga7
+ Revision: 1319071
- Update to 5.1.1
- Add documentation to README.Mageia for setting up with MariaDB

* Tue Oct 09 2018 ngompa <ngompa> 5.1-1.mga7
+ Revision: 1319059
- Update to 5.1

* Sat Sep 29 2018 ngompa <ngompa> 5.0.1-1.mga7
+ Revision: 1311783
- Update to 5.0.1
- Restore symlinks clobbered by the setuptools-created source tarball

* Tue Sep 25 2018 ngompa <ngompa> 5.0-2.mga7
+ Revision: 1303717
- Fix shebangs and Source1 documentation
- Update to 5.0 final

* Thu Sep 20 2018 umeabot <umeabot> 4.93.0-2.mga7
+ Revision: 1281448
- Mageia 7 Mass Rebuild

* Tue Sep 18 2018 ngompa <ngompa> 4.93.0-1.mga7
+ Revision: 1259467
- Update to 4.93.0 (5.0 beta 4)

* Mon Sep 03 2018 ngompa <ngompa> 4.92.0-4.mga7
+ Revision: 1256811
- Fix description reference to README.Mageia

* Sat Sep 01 2018 ngompa <ngompa> 4.92.0-3.mga7
+ Revision: 1256088
- Fix shebangs properly

* Sat Sep 01 2018 ngompa <ngompa> 4.92.0-2.mga7
+ Revision: 1256087
- Fix interpreter path for systemd units

* Sat Sep 01 2018 ngompa <ngompa> 4.92.0-1.mga7
+ Revision: 1256082
- Rebase to v4.92.0 (5.0 beta 3)
- Switch to run on Python 3
- Drop all backports and patches merged upstream

* Sun Jul 22 2018 ngompa <ngompa> 4.0.4-1.mga7
+ Revision: 1244761
- Update to v4.0.4
- Refresh milter config loading patch

* Sun Jun 10 2018 ngompa <ngompa> 4.0.3-2.mga7
+ Revision: 1236165
- Backport support for configurable syntax highlight limit
- Backport fix for pagure-milters
- Refresh default example configuration accordingly
- Add README.Mageia to provide a quick start guide to set up Pagure

* Mon May 28 2018 ngompa <ngompa> 4.0.3-1.mga7
+ Revision: 1232847
- Update to 4.0.3
- Raise gitolite requirement to minimal compatible version
- Drop upstreamed patch to fix generated dependencies

* Tue May 01 2018 ngompa <ngompa> 4.0.1-3.mga7
+ Revision: 1224167
- Fix preun scriptlet for main package
- Filter out more files that dep generators don't need to uselessly process to speed up build

* Tue May 01 2018 ngompa <ngompa> 4.0.1-2.mga7
+ Revision: 1224156
- Fix postun scriptlet for main package
- Imported package pagure from Fedora with adapted packaging for Mageia

